@@ -16,47 +16,44 @@
 import flask
 from oslo_config import cfg
 
+from designate.common import constants
+
 cfg.CONF.import_opt('enable_host_header', 'designate.api', group='service:api')
 
 
+def _add_a_version(versions, version, api_url, status, timestamp):
+    versions.append({
+        'id': version,
+        'status': status,
+        'updated': timestamp,
+        'links': [{'href': api_url,
+                   'rel': 'self'},
+                  {'href': constants.API_REF_URL,
+                   'rel': 'help'}]
+    })
+
+
 def factory(global_config, **local_conf):
     app = flask.Flask('designate.api.versions')
 
-    versions = []
-
-    base = cfg.CONF['service:api'].api_base_uri.rstrip('/')
-
-    def _host_header_links():
-        del versions[:]
-        host_url = flask.request.host_url.rstrip('/')
-        _version('v1', 'DEPRECATED', host_url)
-        _version('v2', 'CURRENT', host_url)
-
-    def _version(version, status, base_uri):
-        versions.append({
-            'id': '%s' % version,
-            'status': status,
-            'links': [{
-                'href': base_uri + '/' + version,
-                'rel': 'self'
-            }]
-        })
-
-    if cfg.CONF['service:api'].enable_api_v1:
-        _version('v1', 'DEPRECATED', base)
-
-    if cfg.CONF['service:api'].enable_api_v2:
-        _version('v2', 'CURRENT', base)
-
     @app.route('/', methods=['GET'])
     def version_list():
         if cfg.CONF['service:api'].enable_host_header:
-            _host_header_links()
+            url_root = flask.request.url_root
+        else:
+            url_root = cfg.CONF['service:api'].api_base_uri
+        api_url = url_root.rstrip('/') + '/v2'
 
-        return flask.jsonify({
-            "versions": {
-                "values": versions
-            }
-        })
+        versions = []
+        # Initial API version for v2 API
+        _add_a_version(versions, 'v2', api_url, constants.SUPPORTED,
+                       '2022-06-29T00:00:00Z')
+        _add_a_version(versions, 'v2.0', api_url, constants.SUPPORTED,
+                       '2022-06-29T00:00:00Z')
+        # 2.1 Shared Zones
+        _add_a_version(versions, 'v2.1', api_url, constants.CURRENT,
+                       '2023-01-25T00:00:00Z')
+
+        return flask.jsonify({'versions': versions})
 
     return app
