@@ -40,7 +40,7 @@ from designate.backend import private_codes
 from designate.conf.agent import DEFAULT_AGENT_PORT
 from designate import dnsutils
 from designate import exceptions
-from designate.mdns import rpcapi as mdns_api
+
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -48,7 +48,6 @@ CONF = cfg.CONF
 
 class AgentPoolBackend(base.Backend):
     __plugin_name__ = 'agent'
-
     __backend_status__ = 'untested'
 
     def __init__(self, target):
@@ -58,16 +57,15 @@ class AgentPoolBackend(base.Backend):
         self.timeout = CONF['service:worker'].poll_timeout
         self.retry_interval = CONF['service:worker'].poll_retry_interval
         self.max_retries = CONF['service:worker'].poll_max_retries
-
         # FIXME: the agent retries creating zones without any interval
 
-    @property
-    def mdns_api(self):
-        return mdns_api.MdnsAPI.get_instance()
+        # TODO(johnsom) Remove this after the agents framework is removed or
+        # the protocol has been updated to not use an unassigned opcode(14).
+        dns.opcode.Opcode = private_codes.OpcodeWith14
 
     def create_zone(self, context, zone):
         LOG.debug('Create Zone')
-        response, retry = self._make_and_send_dns_message(
+        response = self._make_and_send_dns_message(
             zone.name,
             self.timeout,
             private_codes.CC,
@@ -77,25 +75,14 @@ class AgentPoolBackend(base.Backend):
             self.port
         )
         if response is None:
-            raise exceptions.Backend("create_zone() failed")
+            raise exceptions.Backend('Failed create_zone()')
 
     def update_zone(self, context, zone):
         LOG.debug('Update Zone')
 
-        self.mdns_api.notify_zone_changed(
-            context,
-            zone,
-            self.host,
-            self.port,
-            self.timeout,
-            self.retry_interval,
-            self.max_retries,
-            self.delay
-        )
-
     def delete_zone(self, context, zone):
         LOG.debug('Delete Zone')
-        response, retry = self._make_and_send_dns_message(
+        response = self._make_and_send_dns_message(
             zone.name,
             self.timeout,
             private_codes.CC,
@@ -105,61 +92,77 @@ class AgentPoolBackend(base.Backend):
             self.port
         )
         if response is None:
-            raise exceptions.Backend("failed delete_zone()")
+            raise exceptions.Backend('Failed delete_zone()')
 
     def _make_and_send_dns_message(self, zone_name, timeout, opcode,
                                    rdatatype, rdclass, dest_ip,
                                    dest_port):
-        dns_message = self._make_dns_message(zone_name, opcode, rdatatype,
-                                             rdclass)
-
-        retry = 0
-        response = None
-
-        LOG.info("Sending '%(msg)s' for '%(zone)s' to '%(server)s:%(port)d'.",
-                 {'msg': str(opcode),
-                  'zone': zone_name, 'server': dest_ip,
-                  'port': dest_port})
-        response = self._send_dns_message(
-            dns_message, dest_ip, dest_port, timeout)
-
-        if isinstance(response, dns.exception.Timeout):
-            LOG.warning("Got Timeout while trying to send '%(msg)s' for "
-                        "'%(zone)s' to '%(server)s:%(port)d'. "
-                        "Timeout='%(timeout)d' seconds. Retry='%(retry)d'",
-                     {'msg': str(opcode),
-                      'zone': zone_name, 'server': dest_ip,
-                      'port': dest_port, 'timeout': timeout,
-                      'retry': retry})
+        dns_message = self._make_dns_message(
+            zone_name, opcode, rdatatype, rdclass
+        )
+        LOG.info(
+            "Sending '%(msg)s' for '%(zone)s' to '%(server)s:%(port)d'.",
+            {
+                'msg': str(opcode),
+                'zone': zone_name,
+                'server': dest_ip,
+                'port': dest_port
+            }
+        )
+        try:
+            response = dnsutils.send_dns_message(
+                dns_message, dest_ip, port=dest_port, timeout=timeout
+            )
+            # Check that we actually got a NOERROR in the rcode and and an
+            # authoritative answer
+            if not (response.flags & dns.flags.AA) or dns.rcode.from_flags(
+                    response.flags, response.ednsflags) != dns.rcode.NOERROR:
+                LOG.warning(
+                    "Failed to get expected response while trying to "
+                    "send '%(msg)s' for '%(zone)s' to "
+                    "'%(server)s:%(port)d'. Response message: %(resp)s",
+                    {
+                        'msg': str(opcode),
+                        'zone': zone_name,
+                        'server': dest_ip,
+                        'port': dest_port,
+                        'resp': str(response)
+                    }
+                )
+                response = None
+        except dns.exception.Timeout:
+            LOG.warning(
+                "Got Timeout while trying to send '%(msg)s' for "
+                "'%(zone)s' to '%(server)s:%(port)d'. "
+                "Timeout='%(timeout)d' seconds.",
+                {
+                    'msg': str(opcode),
+                    'zone': zone_name,
+                    'server': dest_ip,
+                    'port': dest_port,
+                    'timeout': timeout,
+                }
+            )
             response = None
-        elif isinstance(response, dns.query.BadResponse):
-            LOG.warning("Got BadResponse while trying to send '%(msg)s' for "
-                        "'%(zone)s' to '%(server)s:%(port)d'. "
-                        "Timeout='%(timeout)d' seconds. Retry='%(retry)d'",
-                     {'msg': str(opcode),
-                      'zone': zone_name, 'server': dest_ip,
-                      'port': dest_port, 'timeout': timeout,
-                      'retry': retry})
+        except dns.query.BadResponse:
+            LOG.warning(
+                "Got BadResponse while trying to send '%(msg)s' for "
+                "'%(zone)s' to '%(server)s:%(port)d'. "
+                "Timeout='%(timeout)d' seconds.",
+                {
+                    'msg': str(opcode),
+                    'zone': zone_name,
+                    'server': dest_ip,
+                    'port': dest_port,
+                    'timeout': timeout,
+                }
+            )
             response = None
-            return (response, retry)
-        # Check that we actually got a NOERROR in the rcode and and an
-        # authoritative answer
-        elif not (response.flags & dns.flags.AA) or dns.rcode.from_flags(
-                response.flags, response.ednsflags) != dns.rcode.NOERROR:
-            LOG.warning("Failed to get expected response while trying to "
-                        "send '%(msg)s' for '%(zone)s' to "
-                        "'%(server)s:%(port)d'. Response message: %(resp)s",
-                     {'msg': str(opcode),
-                      'zone': zone_name, 'server': dest_ip,
-                      'port': dest_port, 'resp': str(response)})
-            response = None
-            return (response, retry)
-        else:
-            return (response, retry)
 
-        return (response, retry)
+        return response
 
-    def _make_dns_message(self, zone_name, opcode, rdatatype, rdclass):
+    @staticmethod
+    def _make_dns_message(zone_name, opcode, rdatatype, rdclass):
         dns_message = dns.message.make_query(zone_name, rdatatype,
                                              rdclass=rdclass)
         dns_message.flags = 0
@@ -168,13 +171,3 @@ class AgentPoolBackend(base.Backend):
         dns_message.flags |= dns.flags.AA
 
         return dns_message
-
-    def _send_dns_message(self, dns_message, dest_ip, dest_port, timeout):
-        try:
-            return dnsutils.send_dns_message(
-                dns_message, dest_ip, port=dest_port, timeout=timeout
-            )
-        except dns.exception.Timeout as timeout:
-            return timeout
-        except dns.query.BadResponse as badResponse:
-            return badResponse
