@@ -15,9 +15,12 @@
 # under the License.
 import abc
 
+from debtcollector import removals
+
 from designate.plugin import DriverPlugin
 
 
+@removals.removed_class('AgentBackend')
 class AgentBackend(DriverPlugin):
     """Base class for backend implementations"""
     __plugin_type__ = 'backend'
@@ -48,5 +51,5 @@ class AgentBackend(DriverPlugin):
         """Zone is a DNSPython Zone object"""
 
     @abc.abstractmethod
-    def delete_zone(self, zone_name):
+    def delete_zone(self, zone_name, zone_params):
         """Delete a DNS zone"""
