@@ -37,14 +37,15 @@ Supported Knot versions: >= 2.1, < 3
 
 Configured in [service:agent:knot2]
 """
+import warnings
 
 from oslo_concurrency import lockutils
 from oslo_concurrency.processutils import ProcessExecutionError
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from designate import exceptions
 from designate.backend.agent_backend import base
+from designate import exceptions
 from designate.utils import execute
 
 CFG_GROUP_NAME = 'backend:agent:knot2'
@@ -66,6 +67,12 @@ class Knot2Backend(base.AgentBackend):
         """Configure the backend"""
         super(Knot2Backend, self).__init__(*a, **kw)
 
+        warning_msg = ('The designate agent framework and backend driver "{}" '
+                       'are deprecated as of the Antelope (2023.1) release '
+                       'and will be removed in the "C" '
+                       'release.'.format(self.__plugin_name__))
+        warnings.warn(warning_msg, DeprecationWarning)
+
         self._knotc_cmd_name = cfg.CONF[CFG_GROUP_NAME].knotc_cmd_name
 
     def start(self):
