@@ -12,18 +12,18 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from urllib import parse
 
-import json as jsonutils
-
+from oslo_config import cfg
 from oslo_log import log
+from oslo_serialization import jsonutils
 from oslo_utils import strutils
-from six.moves.urllib import parse
 import requests
 
-from designate.backend.impl_infoblox.config import cfg
 from designate.backend.impl_infoblox import ibexceptions as exc
 
-
+CFG_GROUP_NAME = 'backend:infoblox'
+CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
 
@@ -40,8 +40,7 @@ class Infoblox(object):
         Args:
             options (dict): Target options dictionary
         """
-
-        config = cfg.CONF['backend:infoblox']
+        config = CONF[CFG_GROUP_NAME]
 
         reqd_opts = ['wapi_url', 'username', 'password', 'ns_group']
         other_opts = ['sslverify', 'network_view', 'dns_view', 'multi_tenant']
@@ -62,7 +61,7 @@ class Infoblox(object):
             setattr(self, opt, options.get(opt) or getattr(config, opt))
 
         for opt in reqd_opts:
-            LOG.debug("self.%s = %s" % (opt, getattr(self, opt)))
+            LOG.debug("self.%s = %s", opt, getattr(self, opt))
             if not getattr(self, opt):
                 raise exc.InfobloxIsMisconfigured(option=opt)
 
@@ -90,7 +89,7 @@ class Infoblox(object):
         if extattrs:
             attrs_queries = []
             for key, value in extattrs.items():
-                LOG.debug("key: %s, value: %s" % (key, value))
+                LOG.debug("key: %s, value: %s", key, value)
                 attrs_queries.append('*' + key + '=' + value['value'])
             query += '&'.join(attrs_queries)
         if query_params:
@@ -132,7 +131,10 @@ class Infoblox(object):
 
         headers = {'Content-type': 'application/json'}
 
-        data = jsonutils.dumps(payload)
+        # NOTE (scottsol): This can trigger an internal error in Infoblox if
+        # jsonutils sets it to 'null' (a string with quotes). Setting to None
+        # works around this and returns a valid response from Infoblox
+        data = jsonutils.dump_as_bytes(payload) if payload else None
         url = self._construct_url(objtype, query_params, extattrs)
 
         r = self.session.get(url,
@@ -175,7 +177,7 @@ class Infoblox(object):
         headers = {'Content-type': 'application/json'}
 
         r = self.session.post(url,
-                              data=jsonutils.dumps(payload),
+                              data=jsonutils.dump_as_bytes(payload),
                               verify=self.sslverify,
                               headers=headers)
 
@@ -203,7 +205,7 @@ class Infoblox(object):
 
         headers = {'Content-type': 'application/json'}
         r = self.session.post(url,
-                              data=jsonutils.dumps(payload),
+                              data=jsonutils.dump_as_bytes(payload),
                               verify=self.sslverify,
                               headers=headers)
 
@@ -232,7 +234,7 @@ class Infoblox(object):
 
         headers = {'Content-type': 'application/json'}
         r = self.session.put(self._construct_url(ref),
-                             data=jsonutils.dumps(payload),
+                             data=jsonutils.dump_as_bytes(payload),
                              verify=self.sslverify,
                              headers=headers)
 
