@@ -20,7 +20,6 @@ from oslo_reports import guru_meditation_report as gmr
 
 import designate.conf
 from designate import heartbeat_emitter
-from designate import hookpoints
 from designate import service
 from designate.sink import service as sink_service
 from designate import utils
@@ -36,8 +35,6 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    hookpoints.log_hook_setup()
-
     server = sink_service.Service()
     heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
     service.serve(server, workers=CONF['service:sink'].workers)
