@@ -16,6 +16,7 @@
 from oslo_log import versionutils
 from oslo_policy import policy
 
+from designate.common import constants
 from designate.common.policies import base
 
 DEPRECATED_REASON = """
@@ -106,7 +107,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="create_zone",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Create Zone",
         operations=[
             {
@@ -119,13 +120,13 @@ rules = [
     policy.RuleDefault(
         name="get_zones",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         deprecated_rule=deprecated_get_zones
     ),
     policy.DocumentedRuleDefault(
         name="get_zone",
         check_str=base.SYSTEM_OR_PROJECT_READER_OR_SHARED,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Get Zone",
         operations=[
             {
@@ -138,13 +139,13 @@ rules = [
     policy.RuleDefault(
         name="get_zone_servers",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         deprecated_rule=deprecated_get_zone_servers
     ),
     policy.DocumentedRuleDefault(
         name="get_zone_ns_records",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Get the Name Servers for a Zone",
         operations=[
             {
@@ -157,7 +158,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="find_zones",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="List existing zones",
         operations=[
             {
@@ -170,7 +171,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="update_zone",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Update Zone",
         operations=[
             {
@@ -183,7 +184,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="delete_zone",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Delete Zone",
         operations=[
             {
@@ -196,7 +197,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="xfr_zone",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Manually Trigger an Update of a Secondary Zone",
         operations=[
             {
@@ -209,7 +210,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="abandon_zone",
         check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        scope_types=[constants.PROJECT],
         description="Abandon Zone",
         operations=[
             {
@@ -222,19 +223,19 @@ rules = [
     policy.RuleDefault(
         name="count_zones",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         deprecated_rule=deprecated_count_zones
     ),
     policy.RuleDefault(
         name="count_zones_pending_notify",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         deprecated_rule=deprecated_count_zones_pending_notify
     ),
     policy.RuleDefault(
         name="purge_zones",
         check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        scope_types=[constants.PROJECT],
         deprecated_rule=deprecated_purge_zones
     ),
 ]
