@@ -20,7 +20,8 @@ import re
 import uuid
 
 from oslo_versionedobjects import fields as ovoo_fields
-from oslo_versionedobjects.fields import DateTimeField  # noqa
+
+from designate.common import constants
 
 
 class IntegerField(ovoo_fields.IntegerField):
@@ -46,14 +47,6 @@ class PolymorphicObjectField(ovoo_fields.AutoTypedField):
         super(PolymorphicObjectField, self).__init__(**kwargs)
 
 
-class PolymorphicListOfObjectsField(ovoo_fields.AutoTypedField):
-    def __init__(self, objtype, subclasses=False, **kwargs):
-        self.AUTO_TYPE = ovoo_fields.List(
-            PolymorphicObject(objtype, subclasses))
-        self.objname = objtype
-        super(PolymorphicListOfObjectsField, self).__init__(**kwargs)
-
-
 class ListOfObjectsField(ovoo_fields.ListOfObjectsField):
     pass
 
@@ -91,20 +84,6 @@ class IntegerFields(IntegerField):
 
 
 class StringFields(ovoo_fields.StringField):
-    RE_HOSTNAME = r'^(?!.{255,})(?:(?:^\*|(?!\-)[A-Za-z0-9_\-]{1,63})(?<!\-)\.)+\Z'  # noqa
-    RE_ZONENAME = r'^(?!.{255,})(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-)\.)+\Z'
-    RE_SRV_HOST_NAME = r'^(?:(?!\-)(?:\_[A-Za-z0-9_\-]{1,63}\.){2})(?!.{255,})(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-)\.)+\Z'  # noqa
-    RE_SSHFP_FINGERPRINT = r'^([0-9A-Fa-f]{10,40}|[0-9A-Fa-f]{64})\Z'
-    RE_TLDNAME = r'^(?!.{255,})(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-))(?:\.(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-)))*\Z'  # noqa
-    RE_NAPTR_FLAGS = r'^(?!.*(.).*\1)[APSU]+$'
-    RE_NAPTR_SERVICE = r'^([A-Za-z]([A-Za-z0-9]*)(\+[A-Za-z]([A-Za-z0-9]{0,31}))*)?'  # noqa
-    RE_NAPTR_REGEXP = r'^([^0-9i\\])(.*)\1((.+)|(\\[1-9]))\1(i?)'
-    RE_KVP = r'^\s[A-Za-z0-9]+=[A-Za-z0-9]+'
-    RE_URL_MAIL = r'^mailto:[A-Za-z0-9_\-]+(\+[A-Za-z0-9_\-]+)?@.*'
-    RE_URL_HTTP = r'^http(s)?://.*/'
-    RE_CERT_TYPE = r'(^[A-Z]+$)|(^[0-9]+$)'
-    RE_CERT_ALGO = r'(^[A-Z]+[A-Z0-9\-]+[A-Z0-9]$)|(^[0-9]+$)'
-
     def __init__(self, nullable=False, read_only=False,
                  default=ovoo_fields.UnspecifiedDefault, description='',
                  maxLength=None):
@@ -138,7 +117,7 @@ class UUIDFields(ovoo_fields.AutoTypedField):
     AUTO_TYPE = UUID()
 
 
-class DateTimeField(DateTimeField):
+class DateTimeField(ovoo_fields.DateTimeField):
     def __init__(self, tzinfo_aware=False, **kwargs):
         super(DateTimeField, self).__init__(tzinfo_aware, **kwargs)
 
@@ -207,7 +186,7 @@ class DomainField(StringFields):
                 raise ValueError("Host %s is too long" % host)
         if not value.endswith('.'):
             raise ValueError("Domain %s does not end with a dot" % value)
-        if not re.match(self.RE_ZONENAME, value):
+        if not constants.RE_ZONENAME.match(value):
             raise ValueError("Domain %s is invalid" % value)
         return value
 
@@ -221,7 +200,7 @@ class EmailField(StringFields):
         if value.count('@') != 1:
             raise ValueError("%s is not an email" % value)
         email = value.replace('@', '.')
-        if not re.match(self.RE_ZONENAME, "%s." % email):
+        if not constants.RE_ZONENAME.match("%s." % email):
             raise ValueError("Email %s is invalid" % value)
         return value
 
@@ -240,7 +219,7 @@ class HostField(StringFields):
                 raise ValueError("Host %s is too long" % host)
         if value.endswith('.') is False:
             raise ValueError("Host name %s does not end with a dot" % value)
-        if not re.match(self.RE_HOSTNAME, value):
+        if not constants.RE_HOSTNAME.match(value):
             raise ValueError("Host name %s is invalid" % value)
         return value
 
@@ -259,7 +238,7 @@ class SRVField(StringFields):
                 raise ValueError("Host %s is too long" % host)
         if value.endswith('.') is False:
             raise ValueError("Host name %s does not end with a dot" % value)
-        if not re.match(self.RE_SRV_HOST_NAME, value):
+        if not constants.RE_SRV_HOST_NAME.match(value):
             raise ValueError("Host name %s is not a SRV record" % value)
         return value
 
@@ -281,7 +260,7 @@ class Sshfp(StringFields):
 
     def coerce(self, obj, attr, value):
         value = super(Sshfp, self).coerce(obj, attr, value)
-        if not re.match(self.RE_SSHFP_FINGERPRINT, "%s" % value):
+        if not constants.RE_SSHFP_FINGERPRINT.match("%s" % value):
             raise ValueError("Host name %s is not a SSHFP record" % value)
         return value
 
@@ -292,7 +271,7 @@ class TldField(StringFields):
 
     def coerce(self, obj, attr, value):
         value = super(TldField, self).coerce(obj, attr, value)
-        if not re.match(self.RE_TLDNAME, value):
+        if not constants.RE_TLDNAME.match(value):
             raise ValueError("%s is not a TLD" % value)
         return value
 
@@ -306,7 +285,7 @@ class NaptrFlagsField(StringFields):
         if (len(value) > 255):
             raise ValueError("NAPTR record flags field cannot be longer than"
                              " 255 characters" % value)
-        if not re.match(self.RE_NAPTR_FLAGS, "%s" % value):
+        if not constants.RE_NAPTR_FLAGS.match("%s" % value):
             raise ValueError("NAPTR record flags can be S, A, U and P" % value)
         return value
 
@@ -320,7 +299,7 @@ class NaptrServiceField(StringFields):
         if (len(value) > 255):
             raise ValueError("NAPTR record service field cannot be longer than"
                              " 255 characters" % value)
-        if not re.match(self.RE_NAPTR_SERVICE, "%s" % value):
+        if not constants.RE_NAPTR_SERVICE.match("%s" % value):
             raise ValueError("%s NAPTR record service is invalid" % value)
         return value
 
@@ -335,7 +314,7 @@ class NaptrRegexpField(StringFields):
             raise ValueError("NAPTR record regexp field cannot be longer than"
                              " 255 characters" % value)
         if value:
-            if not re.match(self.RE_NAPTR_REGEXP, "%s" % value):
+            if not constants.RE_NAPTR_REGEXP.match("%s" % value):
                 raise ValueError("%s NAPTR record is invalid" % value)
         return value
 
@@ -357,14 +336,14 @@ class CaaPropertyField(StringFields):
                 if len(host) > 63:
                     raise ValueError("Host %s is too long" % host)
             idn_with_dot = idn + '.'
-            if not re.match(self.RE_ZONENAME, idn_with_dot):
+            if not constants.RE_ZONENAME.match(idn_with_dot):
                 raise ValueError("Domain %s is invalid" % idn)
             for entry in entries:
-                if not re.match(self.RE_KVP, entry):
+                if not constants.RE_KVP.match(entry):
                     raise ValueError("%s is not a valid key-value pair" %
                                      entry)
         elif tag == 'iodef':
-            if re.match(self.RE_URL_MAIL, val):
+            if constants.RE_URL_MAIL.match(val):
                 parts = val.split('@')
                 idn = parts[1]
                 domain = idn.split('.')
@@ -372,9 +351,9 @@ class CaaPropertyField(StringFields):
                     if len(host) > 63:
                         raise ValueError("Host %s is too long" % host)
                 idn_with_dot = idn + '.'
-                if not re.match(self.RE_ZONENAME, idn_with_dot):
+                if not constants.RE_ZONENAME.match(idn_with_dot):
                     raise ValueError("Domain %s is invalid" % idn)
-            elif re.match(self.RE_URL_HTTP, val):
+            elif constants.RE_URL_HTTP.match(val):
                 parts = val.split('/')
                 idn = parts[2]
                 domain = idn.split('.')
@@ -382,7 +361,7 @@ class CaaPropertyField(StringFields):
                     if len(host) > 63:
                         raise ValueError("Host %s is too long" % host)
                 idn_with_dot = idn + '.'
-                if not re.match(self.RE_ZONENAME, idn_with_dot):
+                if not constants.RE_ZONENAME.match(idn_with_dot):
                     raise ValueError("Domain %s is invalid" % idn)
             else:
                 raise ValueError("%s is not a valid URL" % val)
@@ -398,7 +377,7 @@ class CertTypeField(StringFields):
 
     def coerce(self, obj, attr, value):
         value = super(CertTypeField, self).coerce(obj, attr, value)
-        if not re.match(self.RE_CERT_TYPE, "%s" % value):
+        if not constants.RE_CERT_TYPE.match("%s" % value):
             raise ValueError("Cert type %s is not a valid Mnemonic or "
                              "value" % value)
         return value
@@ -410,7 +389,7 @@ class CertAlgoField(StringFields):
 
     def coerce(self, obj, attr, value):
         value = super(CertAlgoField, self).coerce(obj, attr, value)
-        if not re.match(self.RE_CERT_ALGO, "%s" % value):
+        if not constants.RE_CERT_ALGO.match("%s" % value):
             raise ValueError("Cert Algo %s is not a valid Mnemonic or "
                              "value" % value)
         return value
@@ -449,7 +428,7 @@ class IPOrHost(IPV4AndV6AddressField):
         try:
             value = super(IPOrHost, self).coerce(obj, attr, value)
         except ValueError:
-            if not re.match(StringFields.RE_ZONENAME, value):
+            if not constants.RE_ZONENAME.match(value):
                 raise ValueError("%s is not IP address or host name" % value)
         return value
 
@@ -465,7 +444,7 @@ class DenylistFields(StringFields):
             return self._null(obj, attr)
 
         # determine the validity if a regex expression filter has been used.
-        msg = ("%s is not a valid regular expression" % value)
+        msg = "%s is not a valid regular expression" % value
         if not len(value):
             raise ValueError(msg)
         try:
