@@ -19,10 +19,9 @@ import oslo_messaging as messaging
 
 from designate.central import rpcapi
 from designate import coordination
+from designate import exceptions
 from designate.producer import tasks
-from designate import quota
 from designate import service
-from designate import storage
 
 
 LOG = logging.getLogger(__name__)
@@ -51,20 +50,6 @@ class Service(service.RPCService):
             self.service_name, self.tg, grouping_enabled=True
         )
 
-    @property
-    def storage(self):
-        if not self._storage:
-            storage_driver = cfg.CONF['service:producer'].storage_driver
-            self._storage = storage.get_storage(storage_driver)
-        return self._storage
-
-    @property
-    def quota(self):
-        if not self._quota:
-            # Get a quota manager instance
-            self._quota = quota.get_quota()
-        return self._quota
-
     @property
     def service_name(self):
         return 'producer'
@@ -85,9 +70,16 @@ class Service(service.RPCService):
         self._partitioner.start()
         self._partitioner.watch_partition_change(self._rebalance)
 
-        enabled_tasks = CONF['service:producer'].enabled_tasks
-        for task in tasks.PeriodicTask.get_extensions(enabled_tasks):
-            LOG.debug("Registering task %s", task)
+        enabled_tasks = tasks.PeriodicTask.get_extensions(
+            CONF['service:producer'].enabled_tasks
+        )
+        if not enabled_tasks:
+            raise exceptions.ConfigurationError(
+                'No periodic tasks found matching: %s' %
+                CONF['service:producer'].enabled_tasks
+            )
+        for task in enabled_tasks:
+            LOG.debug('Registering task %s', task)
 
             # Instantiate the task
             task = task()
@@ -103,5 +95,5 @@ class Service(service.RPCService):
         self.coordination.stop()
 
     def _rebalance(self, my_partitions, members, event):
-        LOG.info("Received rebalance event %s", event)
+        LOG.info('Received rebalance event %s', event)
         self.partition_range = my_partitions
