@@ -11,17 +11,18 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import functools
-import threading
 
 from oslo_config import cfg
 import oslo_messaging as messaging
 from oslo_messaging.rpc import dispatcher as rpc_dispatcher
 from oslo_serialization import jsonutils
+from oslo_utils import importutils
 
-from designate import objects
 import designate.context
 import designate.exceptions
+from designate import objects
+
+profiler = importutils.try_import('osprofiler.profiler')
 
 __all__ = [
     'init',
@@ -37,7 +38,6 @@ __all__ = [
 ]
 
 CONF = cfg.CONF
-EXPECTED_EXCEPTION = threading.local()
 NOTIFICATION_TRANSPORT = None
 NOTIFIER = None
 TRANSPORT = None
@@ -151,9 +151,23 @@ class RequestContextSerializer(messaging.Serializer):
         return self._base.deserialize_entity(context, entity)
 
     def serialize_context(self, context):
-        return context.to_dict()
+        _context = context.to_dict()
+        if profiler is not None:
+            prof = profiler.get()
+            if prof is not None:
+                trace_info = {
+                    "hmac_key": prof.hmac_key,
+                    "base_id": prof.get_base_id(),
+                    "parent_id": prof.get_id()
+                }
+                _context.update({"trace_info": trace_info})
+        return _context
 
     def deserialize_context(self, context):
+        trace_info = context.pop("trace_info", None)
+        if trace_info is not None:
+            if profiler is not None:
+                profiler.init(**trace_info)
         return designate.context.DesignateContext.from_dict(context)
 
 
@@ -167,7 +181,7 @@ def get_client(target, version_cap=None, serializer=None):
     if serializer is None:
         serializer = DesignateObjectSerializer()
     serializer = RequestContextSerializer(serializer)
-    return messaging.RPCClient(
+    return messaging.get_rpc_client(
         TRANSPORT,
         target,
         version_cap=version_cap,
@@ -220,27 +234,3 @@ def create_transport(url):
     return messaging.get_rpc_transport(CONF,
                                        url=url,
                                        allowed_remote_exmods=exmods)
-
-
-def expected_exceptions():
-    def outer(f):
-        @functools.wraps(f)
-        def exception_wrapper(self, *args, **kwargs):
-            if not hasattr(EXPECTED_EXCEPTION, 'depth'):
-                EXPECTED_EXCEPTION.depth = 0
-            EXPECTED_EXCEPTION.depth += 1
-
-            # We only want to wrap the first function wrapped.
-            if EXPECTED_EXCEPTION.depth > 1:
-                return f(self, *args, **kwargs)
-
-            try:
-                return f(self, *args, **kwargs)
-            except designate.exceptions.DesignateException as e:
-                if e.expected:
-                    raise rpc_dispatcher.ExpectedException()
-                raise
-            finally:
-                EXPECTED_EXCEPTION.depth = 0
-        return exception_wrapper
-    return outer
