@@ -122,14 +122,16 @@ zones = Table('zones', metadata,
     Column('description', Unicode(160), nullable=True),
     Column("type", Enum(name='type', *ZONE_TYPES), nullable=False),
     Column('transferred_at', DateTime, default=None),
-    Column('ttl', Integer, default=CONF.default_ttl, nullable=False),
+    Column('ttl', Integer, default=lambda: CONF.default_ttl, nullable=False),
     Column('serial', Integer, default=timeutils.utcnow_ts, nullable=False),
     # The refresh interval is randomized by _generate_soa_refresh_interval
-    Column('refresh', Integer, default=CONF.default_soa_refresh_min,
+    Column('refresh', Integer, default=lambda: CONF.default_soa_refresh_min,
            nullable=False),
-    Column('retry', Integer, default=CONF.default_soa_retry, nullable=False),
-    Column('expire', Integer, default=CONF.default_soa_expire, nullable=False),
-    Column('minimum', Integer, default=CONF.default_soa_minimum,
+    Column('retry', Integer, default=lambda: CONF.default_soa_retry,
+           nullable=False),
+    Column('expire', Integer, default=lambda: CONF.default_soa_expire,
+           nullable=False),
+    Column('minimum', Integer, default=lambda: CONF.default_soa_minimum,
            nullable=False),
     Column('status', Enum(name='zones_resource_statuses', *RESOURCE_STATUSES),
            nullable=False, server_default='PENDING', default='PENDING'),
