@@ -20,7 +20,7 @@ from webtest import TestApp
 
 from designate.api import middleware
 from designate.api import v2 as api_v2
-from designate.tests.test_api import ApiTestCase
+import designate.tests
 
 
 LOG = logging.getLogger(__name__)
@@ -33,13 +33,10 @@ INVALID_ID = [
 ]
 
 
-class ApiV2TestCase(ApiTestCase):
+class ApiV2TestCase(designate.tests.TestCase):
     def setUp(self):
         super(ApiV2TestCase, self).setUp()
 
-        # Ensure the v2 API is enabled
-        self.config(enable_api_v2=True, group='service:api')
-
         # Create the application
         self.app = api_v2.factory({})
 
@@ -123,7 +120,8 @@ class ApiV2TestCase(ApiTestCase):
             if marker is not None:
                 params['marker'] = marker
 
-            r = self.client.get(url, params, status=expected_status)
+            r = self.client.get(url, params, status=expected_status,
+                                headers={'X-Test-Role': 'member'})
             if expected_status != 200:
                 if expected_type:
                     self._assert_exception(expected_type, expected_status, r)
