@@ -189,8 +189,7 @@ class ApiV2PoolsTest(ApiV2TestCase):
 
         correct_results = [1, 1, 0]
 
-        for get_url, correct_result in \
-                zip(get_urls, correct_results):
+        for get_url, correct_result in zip(get_urls, correct_results):
 
             response = self.client.get(get_url)
 
