@@ -16,8 +16,7 @@
 from oslo_log import log as logging
 
 from designate.notification_handler.neutron import NeutronFloatingHandler
-from designate.tests.test_notification_handler import \
-    NotificationHandlerMixin
+from designate.tests.test_notification_handler import NotificationHandlerMixin
 from designate.tests import TestCase
 
 LOG = logging.getLogger(__name__)
