@@ -13,29 +13,37 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+from unittest import mock
+
+import oslotest.base
 import requests_mock
 
 from designate.backend import impl_ns1
+from designate import context
 from designate import exceptions
 from designate import objects
-import designate.tests
 from designate.tests import fixtures
 
 
-class NS1BackendTestCase(designate.tests.TestCase):
+class NS1BackendTestCase(oslotest.base.BaseTestCase):
     def setUp(self):
         super(NS1BackendTestCase, self).setUp()
         self.stdlog = fixtures.StandardLogging()
         self.useFixture(self.stdlog)
 
+        self.context = mock.Mock()
+        self.admin_context = mock.Mock()
+        mock.patch.object(
+            context.DesignateContext, 'get_admin_context',
+            return_value=self.admin_context).start()
+
         self.api_address = 'https://192.0.2.3/v1/zones/example.com'
-        self.context = self.get_context()
         self.zone = objects.Zone(
             id='e2bed4dc-9d01-11e4-89d3-123b93f75cba',
             name='example.com.',
             email='example@example.com',
         )
-
         self.target = {
             'id': '4588652b-50e7-46b9-b688-a9bad40a873e',
             'type': 'ns1',
@@ -64,7 +72,7 @@ class NS1BackendTestCase(designate.tests.TestCase):
             ],
         }
         self.put_request_json = {
-            'zone': u'example.com',
+            'zone': 'example.com',
             'secondary': {
                 'enabled': True,
                 'primary_ip': '192.0.2.1',
@@ -72,7 +80,7 @@ class NS1BackendTestCase(designate.tests.TestCase):
             }
         }
         self.put_request_tsig_json = {
-            'zone': u'example.com',
+            'zone': 'example.com',
             'secondary': {
                 'enabled': True,
                 'primary_ip': '192.0.2.1',
