@@ -16,6 +16,8 @@
 import itertools
 from unittest import mock
 
+from oslo_config import cfg
+from oslo_config import fixture as cfg_fixture
 from oslo_log import log as logging
 import oslotest.base
 
@@ -23,11 +25,14 @@ from designate import exceptions
 from designate import objects
 from designate.objects.adapters import DesignateAdapter
 
+CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
 def create_test_recordset():
     record_set = objects.RecordSet(
+        id='f6a2cbd6-7f9a-4e0c-a00d-98a02aa73fc8',
+        zone_id='74038683-cab1-4056-bdf8-b39bd155ff21',
         name='www.example.org.',
         type='A',
         records=objects.RecordList(objects=[
@@ -39,12 +44,24 @@ def create_test_recordset():
 
 
 class RecordSetTest(oslotest.base.BaseTestCase):
+    def setUp(self):
+        super(RecordSetTest, self).setUp()
+        self.useFixture(cfg_fixture.Config(CONF))
 
     def test_init(self):
         record_set = create_test_recordset()
         self.assertEqual('www.example.org.', record_set.name)
         self.assertEqual('A', record_set.type)
 
+    def test_to_repr(self):
+        record_set = create_test_recordset()
+        self.assertEqual(
+            "<RecordSet id:'f6a2cbd6-7f9a-4e0c-a00d-98a02aa73fc8' type:'A' "
+            "name:'www.example.org.' "
+            "zone_id:'74038683-cab1-4056-bdf8-b39bd155ff21'>",
+            repr(record_set)
+        )
+
     def test_not_managed(self):
         record_set = create_test_recordset()
         self.assertFalse(record_set.managed)
@@ -217,6 +234,47 @@ class RecordSetTest(oslotest.base.BaseTestCase):
         record_set = create_test_recordset()
         record_set.validate()
 
+    def test_validate_attribute_error(self):
+        record_set = objects.RecordSet(
+            name='www.example.org.',
+            type='NAPTR',
+            records=objects.RecordList(objects=[
+                objects.Record(data=None),
+            ])
+        )
+        self.assertRaisesRegex(
+            exceptions.InvalidObject,
+            'Provided object does not match schema',
+            record_set.validate
+        )
+
+    def test_validate_type_error(self):
+        record_set = objects.RecordSet(
+            name='www.example.org.',
+            type='TXT',
+            records=objects.RecordList(objects=[
+                objects.Record(data=None),
+            ])
+        )
+        self.assertRaisesRegex(
+            exceptions.InvalidObject,
+            'Provided object does not match schema',
+            record_set.validate
+        )
+
+    def test_validate_unsupported_recordset_type(self):
+        CONF.set_override('supported_record_type', ['A', 'AAAA', 'CNAME'])
+
+        record_set = objects.RecordSet(
+            name='www.example.org.', type='PTR',
+            records=[]
+        )
+        self.assertRaisesRegex(
+            exceptions.InvalidObject,
+            'Provided object does not match schema',
+            record_set.validate
+        )
+
     def test_validate_handle_exception(self):
         record_set = create_test_recordset()
         rs_module = record_set.__class__.__bases__[0].__module__
