@@ -23,10 +23,10 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import timeutils
 
+from designate.common import constants
 from designate import dnsutils
 from designate import exceptions
 from designate import objects
-from designate import utils
 from designate.worker.tasks import base
 
 LOG = logging.getLogger(__name__)
@@ -168,6 +168,9 @@ class ZoneXfr(base.Task):
         self.servers = servers
 
     def __call__(self):
+        if self.zone.type != constants.ZONE_SECONDARY:
+            return
+
         servers = self.servers or self.zone.masters
         if isinstance(servers, objects.ListObjectMixin):
             servers = servers.to_list()
@@ -180,7 +183,7 @@ class ZoneXfr(base.Task):
 
         self.zone.update(dnsutils.from_dnspython_zone(dnspython_zone))
         self.zone.transferred_at = timeutils.utcnow()
-        self.zone.obj_reset_changes(['name'])
+        self.zone.obj_reset_changes(['name', 'masters'], recursive=True)
         self.central_api.update_zone(
             self.context, self.zone, increment_serial=False
         )
@@ -795,11 +798,10 @@ class RecoverShard(base.Task):
         # Include things that have been hanging out in PENDING
         # status for longer than they should
         # Generate the current serial, will provide a UTC Unix TS.
-        current = utils.increment_serial()
         stale_criterion = {
             'shard': "BETWEEN %s,%s" % (self.begin_shard, self.end_shard),
             'status': 'PENDING',
-            'serial': "<%s" % (current - self.max_prop_time)
+            'serial': "<%s" % (timeutils.utcnow_ts() - self.max_prop_time)
         }
 
         stale_zones = self.storage.find_zones(self.context, stale_criterion)
